@import url(../../sections/sections.css);
/*  screen.css - MoinMoin Default Styles

Copyright (c) 2001, 2002, 2003 by Juergen Hermann
*/

/* content styles */

/* debug 
div, ul {border: 1px dotted blue; }
*/
html {
    background: url(../img/undef.gif) left center no-repeat fixed #fff;
}

body {
}

a:link {
    /*color: #7F2A00;*/
    color: #2a3674;
    border-bottom: 1px dashed #5f6db0;
    text-decoration: none;
}
a:visited {
    color: #222;    
    text-decoration: none;
    border-bottom: 1px dashed #5f6db0;
}
a.nonexistent, a.badinterwiki {
    color: #6a0000;    
    text-decoration: none;
    border-bottom: 1px solid #bc0000;
}
a:hover {
    color: #000;
    background-color: #eaeaea;
    border-bottom: 1px solid #000;
}

input {
    font-size: 1em;
    font-family: Arial, Lucida Grande, sans-serif;
}

textarea {
    font-size: 1em;
    font-family: monospace;
}

.footnotes div {
	width: 5em;
	border-top: 1px solid gray;
}

/* user interface styles */

#logo {
	/* contains image and/or text link */
        text-align: center;
	font-size: 1em;
	line-height: 1.2em;
	font-weight: bold;
	margin: 2em 0;
	padding: 0;
}

#logo img {
	/* logo image */
	vertical-align: middle;
        display: block;
        margin: 0 auto;
}

#logo a {
	/* logo text link */
	color: black;  
	text-decoration: none;
	white-space: nowrap;
        border: none;
}

#title h1 {
	margin: 0;
	padding: 0;    
	font-size: 2em;
	font-weight: bold;
	line-height: 1.2;
}

#title h1 a {
	text-decoration: none;
}

#searchform {
	margin: 0;
	padding: 0;
        width: 100%;
        text-align: center;
}

#searchform form div {
        width: 100%;
}
#searchinput {
    display: block;
    width: 100%;
    margin: 0.25em 0;
    border: 1px solid #999;
    background: #fff;
    text-align: left;
}

#iconbar {
	margin: 0;
	padding: 0;
}

#iconbar li {
	display: inline;
	padding: 0;
	margin: 0 2px;
}

#iconbar a {
    border: none;
}

#actions,
#pagetrail,
#username, 
#navibar {
	margin: 0.25em 0;
	padding: 0.25em 0;
	font-size: 0.88em;
        border-bottom: 1px dashed #999;
}

#actions a,
#pagetrail a,
#username a,
#navibar a {
        padding: 0.25em;
	text-decoration: none;
	display: block;
        border: none;
}

#actions li,
#pagetrail li,
#username li,
#navibar li {
	display: block;
        margin: 0;
        padding: 0;
        line-height: 1.2em;
}

#navibar li.wikilink {
}

#navibar li.userlink a {
    font-style: italic;
}

#navibar li.current a {
	font-weight: bold;
}

#message p { 
    margin: 0; 
    padding: 0; 
}
#message { 
    position: absolute;
    top: 0.5em;
    left: 0.5em;
    width: 16em;
    color: #222; 
    padding: 1em; 
    margin: 1em 0;
    border: 1px solid #eee;
    background: url(../img/undef2.gif) left center no-repeat fixed #fff;
    
} 
#message .buttons { text-align: right; font-size: small; }
#message a { color: #731; }
#message a:hover { background: #e5e5e5; }

form.dialog {
    margin: 0 15px;
}

.dialog td {
    border: none;
    padding: 5px;
}

.dialog td.label {
    text-align: right;
    font-weight: bold;
    width: 25%;
}

*[dir="rtl"] .dialog td.label {
    text-align: left;
}

.dialog td.content input {
    width: 100%;
}

#page {
    padding: 1em;
    min-height: 30em;
    border: 1px solid #eee;
    background: url(../img/undef2.gif) left center no-repeat fixed #fff;
}

/* min-height replacement for IE */
* html #page {
    height: 30em;
    background: white;
}


/* We use here dumb css1 ids becuase of IE suckiness */
#editor-textarea, #editor-comment {
    width: 100%;
}

#editor-textarea {
    background: #fff;
    border: 1px solid #eee;
    padding: 0.25em;
}

#footer {
	clear: both;
	padding: 0.5em;
	font-size: small;
    background: url(../img/shadow2.gif) no-repeat right top;
}

#footer p, #footer form {
	margin: 0.25em 0;
}

#credits, #version, #timings{
	margin: 5px 0;
	padding: 0;
	text-align: center;
	font-size: 0.82em;
	color: gray;
}

#credits li, #timings li {
	display: block;
        list-style: none;
	padding: 0 2px;
}

#credits img {
	vertical-align: middle;
}

#preview {
	border: 1px solid #gray;
	padding: .5em;
	background: url(../img/draft.png);
}

.diff {
	width:99%;
}

.diff-header {
	font-weight: bold;
}

.diff-title {
	background-color: #C0C0C0;
}

.diff-added {
	background-color: #E0FFE0;
	vertical-align: sub;
}

.diff-removed {
	background-color: #FFFFE0;
	vertical-align: sub;
}

.diff-added span {
	background-color: #80FF80;
}

.diff-removed span {
	background-color: #FFFF80;
}

.searchresult dd span {
	font-weight: bold;
}

#menu {
    width: 9em;
    background: url(../img/shadow.gif) no-repeat top left;
    padding: 0.5em;
    margin: 0;
    position: absolute;
    top: 1em;
    right: 0.5em;
}

/* IE's different box model */
* html #menu {
    right: 0;
    margin-right: -3px;
}


#container {
    width: 40em;
    padding: 0;
    margin: 1em 10em 1em auto;
    height: auto;
}
