/*  common.css - MoinMoin Default Styles

Copyright (c) 2001, 2002, 2003 by Juergen Hermann
*/

html {
	color: black;
	font-family: Arial, Lucida Grande, sans-serif;
	font-size: 1em;
	line-height: 1.25em;
}

/* Headings */

h1 {
	margin: 0;
	padding: 0;
	font-size: 2em;
	color: black;
	font-weight: bold; 
	line-height: 1.2em;
        clear: both;
}

h2, h3, h4, h5, h6
{
	margin: 1.5em 0 0 0;
	padding: 2px 5px;
	font-weight: bold; 
	color: black;
	line-height: 1.2em;
        border-bottom: 2px solid #5f6db0;
	color: black;
        clear: both;
}	

h2 {font-size: 1.6em;}
h3 {font-size: 1.3em;}
h4 {font-size: 1.1em;}
h5, h6 {font-size: 1em;}

li p {
	margin: .25em 0;
}

li.gap {
	margin-top: 0.5em;
}

a, img, img.drawing {
	border: 0;
}

dt {
	font-weight: bold;
}

pre {
	padding: 5px;
	font-family: courier, monospace;
	white-space: pre;
	/* begin css 3 or browser specific rules - do not remove!
	see: http://forums.techguy.org/archive/index.php/t-249849.html */
    white-space: pre-wrap;
    word-wrap: break-word;
    white-space: -moz-pre-wrap;
    white-space: -pre-wrap;
    white-space: -o-pre-wrap;
    /* end css 3 or browser specific rules */
}

table {
	margin: 0.5em 0;
	border-collapse: collapse;
}

td
{
	padding: 0.25em;
	border: 1px solid #c0c0c0;
}

td p {
	margin: 0;
	padding: 0;
}

/* standard rule ---- */
hr {
	clear: both;
	height: 2px;
	background-color: #c0c0c0;
	border: none;
}

/* custom rules ----- to ---------- */
.hr1 {height: 3px;}
.hr2 {height: 4px;}
.hr3 {height: 5px;}
.hr4 {height: 6px;}
.hr5 {height: 7px;}
.hr6 {height: 8px;}

/* Replacement for html 3 u tag */
.u {text-decoration: underline;}

.footnotes ul {
	padding: 0 2em;
	margin: 0 0 1em;
	list-style: none;
}

.footnotes li {
}


/* eye catchers */
.warning 
{
	color: red;
}

.error 
{
	color: red;
}

strong.highlight 
{
	background-color: #d9dcee;
	padding: 1pt;
}


/* Recent changes */

div.recentchanges table {
	border: 1px solid #d9dcee; 
}

.recentchanges p {
	margin: 0.25em;
}

.recentchanges td {
	border: none;
	border-top: 1px solid #e5e5e5;
	border-bottom: 1px solid #e5e5e5;
	vertical-align: top;
}

.rcdaybreak {
	background-color: #d9dcee;
}

.rcdaybreak td a {
	font-size: 0.88em;
}

.rcicon1, .rcicon2 {
	text-align: center;
}

.rcpagelink {
	width: 33%;
}

.rctime {
	font-size: 0.88em;
	white-space: nowrap;
}

.rceditor {
	white-space: nowrap;
	font-size: 0.88em;
}

.rccomment {
	width: 66%;
	color: gray;
	font-size: 0.88em;
}

.rcrss {
	float: right;
}

.recentchanges[dir="rtl"] .rcrss {
	float: left;
}

/* User Preferences */

.userpref table, .userpref td {
	border: none;
}

/* CSS for new code_area markup used by Colorizer and ParserBase */

div.codearea { /* the div makes the border */
	margin: 0.5em;
	padding: 0.5em;
	background-color: #eee;
	color: black;
    -moz-border-radius: 0.5em; 
}

div.codearea pre { /* the pre has no border and is inside the div */
	margin: 0;
	padding: 10pt;
	border: none;
}

a.codenumbers { /* format of the line numbering link */
	margin: 0 10pt;
	font-size: 0.85em;
	color: gray;
}

/* format of certain syntax spans */
div.codearea pre span.LineNumber {color: gray;}
div.codearea pre span.ID         {color: #000000;}
div.codearea pre span.Operator   {color: #0000C0;}
div.codearea pre span.Char       {color: #004080;}
div.codearea pre span.Comment    {color: #008000;}
div.codearea pre span.Number     {color: #0080C0;}
div.codearea pre span.String     {color: #004080;}
div.codearea pre span.SPChar     {color: #0000C0;}
div.codearea pre span.ResWord    {color: #A00000;}
div.codearea pre span.ConsWord   {color: #008080; font-weight: bold;}
div.codearea pre span.Error      {color: #FF8080; border: solid 1.5pt #FF0000;}
div.codearea pre span.ResWord2   {color: #0080ff; font-weight: bold;}
div.codearea pre span.Special    {color: #0000ff;}
div.codearea pre span.Preprc     {color: #803999;}


